#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
测试API包装器模块
Test API wrapper module
"""

import pytest
from unittest.mock import Mock, patch
from everytools.core.api_wrapper import EverythingAPI
from everytools.constants import SortType, RequestFlag


class TestEverythingAPI:
    """测试EverythingAPI类"""

    def setup_method(self):
        """设置测试方法"""
        with patch("everytools.core.api_wrapper.get_dll_loader") as mock_loader:
            mock_dll = Mock()
            mock_loader.return_value.everything_dll = mock_dll
            self.api = EverythingAPI()
            self.mock_dll = mock_dll

    def test_init(self):
        """测试初始化"""
        with patch("everytools.core.api_wrapper.get_dll_loader") as mock_loader:
            mock_dll = Mock()
            mock_loader.return_value.everything_dll = mock_dll
            api = EverythingAPI(machine=64)
            mock_loader.assert_called_once_with(64)
            assert api._dll == mock_dll

    def test_set_search(self):
        """测试设置搜索字符串"""
        self.api.set_search("test")
        self.mock_dll.Everything_SetSearchW.assert_called_once_with("test")

    def test_set_match_path(self):
        """测试设置匹配路径"""
        self.api.set_match_path(True)
        self.mock_dll.Everything_SetMatchPath.assert_called_once_with(True)

    def test_set_match_case(self):
        """测试设置区分大小写"""
        self.api.set_match_case(True)
        self.mock_dll.Everything_SetMatchCase.assert_called_once_with(True)

    def test_set_match_whole_word(self):
        """测试设置全字匹配"""
        self.api.set_match_whole_word(True)
        self.mock_dll.Everything_SetMatchWholeWord.assert_called_once_with(True)

    def test_set_regex(self):
        """测试设置正则表达式"""
        self.api.set_regex(True)
        self.mock_dll.Everything_SetRegex.assert_called_once_with(True)

    def test_set_max(self):
        """测试设置最大结果数"""
        self.api.set_max(100)
        self.mock_dll.Everything_SetMax.assert_called_once_with(100)

    def test_set_offset(self):
        """测试设置偏移量"""
        self.api.set_offset(50)
        self.mock_dll.Everything_SetOffset.assert_called_once_with(50)
