#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
测试配置模块
"""

import pytest
from everytools import config


def test_sort_constants():
    """测试排序常量定义"""
    # 测试基本排序常量
    assert config.EVERYTHING_SORT_NAME_ASCENDING == 1
    assert config.EVERYTHING_SORT_NAME_DESCENDING == 2
    assert config.EVERYTHING_SORT_PATH_ASCENDING == 3
    assert config.EVERYTHING_SORT_PATH_DESCENDING == 4
    assert config.EVERYTHING_SORT_SIZE_ASCENDING == 5
    assert config.EVERYTHING_SORT_SIZE_DESCENDING == 6

    # 测试扩展名排序常量
    assert config.EVERYTHING_SORT_EXTENSION_ASCENDING == 7
    assert config.EVERYTHING_SORT_EXTENSION_DESCENDING == 8

    # 测试类型排序常量
    assert config.EVERYTHING_SORT_TYPE_NAME_ASCENDING == 9
    assert config.EVERYTHING_SORT_TYPE_NAME_DESCENDING == 10

    # 测试日期排序常量
    assert config.EVERYTHING_SORT_DATE_CREATED_ASCENDING == 11
    assert config.EVERYTHING_SORT_DATE_CREATED_DESCENDING == 12
    assert config.EVERYTHING_SORT_DATE_MODIFIED_ASCENDING == 13
    assert config.EVERYTHING_SORT_DATE_MODIFIED_DESCENDING == 14

    # 测试属性排序常量
    assert config.EVERYTHING_SORT_ATTRIBUTES_ASCENDING == 15
    assert config.EVERYTHING_SORT_ATTRIBUTES_DESCENDING == 16

    # 测试文件列表排序常量
    assert config.EVERYTHING_SORT_FILE_LIST_FILENAME_ASCENDING == 17
    assert config.EVERYTHING_SORT_FILE_LIST_FILENAME_DESCENDING == 18

    # 测试运行次数排序常量
    assert config.EVERYTHING_SORT_RUN_COUNT_ASCENDING == 19
    assert config.EVERYTHING_SORT_RUN_COUNT_DESCENDING == 20

    # 测试最近更改排序常量
    assert config.EVERYTHING_SORT_DATE_RECENTLY_CHANGED_ASCENDING == 21
    assert config.EVERYTHING_SORT_DATE_RECENTLY_CHANGED_DESCENDING == 22

    # 测试访问时间排序常量
    assert config.EVERYTHING_SORT_DATE_ACCESSED_ASCENDING == 23
    assert config.EVERYTHING_SORT_DATE_ACCESSED_DESCENDING == 24

    # 测试运行时间排序常量
    assert config.EVERYTHING_SORT_DATE_RUN_ASCENDING == 25
    assert config.EVERYTHING_SORT_DATE_RUN_DESCENDING == 26


def test_sort_constants_uniqueness():
    """测试排序常量的唯一性"""
    constants = [
        config.EVERYTHING_SORT_NAME_ASCENDING,
        config.EVERYTHING_SORT_NAME_DESCENDING,
        config.EVERYTHING_SORT_PATH_ASCENDING,
        config.EVERYTHING_SORT_PATH_DESCENDING,
        config.EVERYTHING_SORT_SIZE_ASCENDING,
        config.EVERYTHING_SORT_SIZE_DESCENDING,
        config.EVERYTHING_SORT_EXTENSION_ASCENDING,
        config.EVERYTHING_SORT_EXTENSION_DESCENDING,
        config.EVERYTHING_SORT_TYPE_NAME_ASCENDING,
        config.EVERYTHING_SORT_TYPE_NAME_DESCENDING,
        config.EVERYTHING_SORT_DATE_CREATED_ASCENDING,
        config.EVERYTHING_SORT_DATE_CREATED_DESCENDING,
        config.EVERYTHING_SORT_DATE_MODIFIED_ASCENDING,
        config.EVERYTHING_SORT_DATE_MODIFIED_DESCENDING,
        config.EVERYTHING_SORT_ATTRIBUTES_ASCENDING,
        config.EVERYTHING_SORT_ATTRIBUTES_DESCENDING,
        config.EVERYTHING_SORT_FILE_LIST_FILENAME_ASCENDING,
        config.EVERYTHING_SORT_FILE_LIST_FILENAME_DESCENDING,
        config.EVERYTHING_SORT_RUN_COUNT_ASCENDING,
        config.EVERYTHING_SORT_RUN_COUNT_DESCENDING,
        config.EVERYTHING_SORT_DATE_RECENTLY_CHANGED_ASCENDING,
        config.EVERYTHING_SORT_DATE_RECENTLY_CHANGED_DESCENDING,
        config.EVERYTHING_SORT_DATE_ACCESSED_ASCENDING,
        config.EVERYTHING_SORT_DATE_ACCESSED_DESCENDING,
        config.EVERYTHING_SORT_DATE_RUN_ASCENDING,
        config.EVERYTHING_SORT_DATE_RUN_DESCENDING,
    ]

    # 检查所有常量都是唯一的
    assert len(constants) == len(set(constants))

    # 检查常量值的范围
    assert all(1 <= const <= 26 for const in constants)


def test_sort_constants_types():
    """测试排序常量的类型"""
    # 所有排序常量都应该是整数
    assert isinstance(config.EVERYTHING_SORT_NAME_ASCENDING, int)
    assert isinstance(config.EVERYTHING_SORT_NAME_DESCENDING, int)
    assert isinstance(config.EVERYTHING_SORT_PATH_ASCENDING, int)
    assert isinstance(config.EVERYTHING_SORT_PATH_DESCENDING, int)
    assert isinstance(config.EVERYTHING_SORT_SIZE_ASCENDING, int)
    assert isinstance(config.EVERYTHING_SORT_SIZE_DESCENDING, int)
